@@ -2,10 +2,14 @@
 
 from __future__ import annotations
 
+import logging
 import os.path
+import sqlite3
 from datetime import datetime
 from enum import Enum
 
+logger: logging.Logger = logging.getLogger("osxphotos")
+
 APP_NAME = "osxphotos"
 
 OSXPHOTOS_URL = "https://github.com/RhetTbull/osxphotos"
@@ -14,23 +18,23 @@ OSXPHOTOS_URL = "https://github.com/RhetTbull/osxphotos"
 # Apple Epoch is Jan 1, 2001
 TIME_DELTA = (datetime(2001, 1, 1, 0, 0) - datetime(1970, 1, 1, 0, 0)).total_seconds()
 
-# Unicode format to use for comparing strings
-UNICODE_FORMAT = "NFC"
-
 # which Photos library database versions have been tested
 # Photos 2.0 (10.12.6) == 2622
 # Photos 3.0 (10.13.6) == 3301
 # Photos 4.0 (10.14.5) == 4016
 # Photos 4.0 (10.14.6) == 4025
-# Photos 5.0 (10.15.0) == 6000 or 5001
+# Photos 5.0+ (10.15.0) == 6000 or 5001
 _TESTED_DB_VERSIONS = ["6000", "5001", "4025", "4016", "3301", "2622"]
 
-# database model versions (applies to Photos 5, Photos 6)
+# database model versions (applies to Photos 5+)
 # these come from PLModelVersion key in binary plist in Z_METADATA.Z_PLIST
 # Photos 5 (10.15.1) == 13537
 # Photos 5 (10.15.4, 10.15.5, 10.15.6) == 13703
 # Photos 6 (10.16.0 Beta) == 14104
-_TEST_MODEL_VERSIONS = ["13537", "13703", "14104"]
+# Photos 7 (12.0.1) == 15323
+# Photos 8 (13.0.0) == 16320
+# Photos 9 (14.0.0 dev preview) = 17120
+_TEST_MODEL_VERSIONS = ["13537", "13703", "14104", "15323", "16320", "17120"]
 
 _PHOTOS_2_VERSION = "2622"
 
@@ -38,7 +42,7 @@ _PHOTOS_2_VERSION = "2622"
 _PHOTOS_3_VERSION = "3301"
 
 # versions 5.0 and later have a different database structure
-_PHOTOS_4_VERSION = "4025"  # latest Mojove version on 10.14.6
+_PHOTOS_4_VERSION = "4025"  # latest Mojave version on 10.14.6
 _PHOTOS_5_VERSION = "5000"  # I've seen both 5001 and 6000.  6000 is most common on Catalina and up but there are some version 5001 database in the wild
 
 # Ranges for model version by Photos version
@@ -46,8 +50,15 @@ _PHOTOS_5_MODEL_VERSION = [13000, 13999]
 _PHOTOS_6_MODEL_VERSION = [14000, 14999]
 _PHOTOS_7_MODEL_VERSION = [15000, 15999]  # Dev preview: 15134, 12.1: 15331
 _PHOTOS_8_MODEL_VERSION = [16000, 16999]  # Ventura dev preview: 16119
+_PHOTOS_9_MODEL_VERSION = [17000, 17999]  # Sonoma dev preview: 17120
 
-# some table names differ between Photos 5 and Photos 6
+# the preview versions of 12.0.0 had a difference schema for syndication info so need to check model version before processing
+_PHOTOS_SYNDICATION_MODEL_VERSION = 15323  # 12.0.1
+
+# shared iCloud library versions; dev preview doesn't contain same columns as release version
+_PHOTOS_SHARED_LIBRARY_VERSION = 16320  # 13.0
+
+# some table names differ between Photos 5 and later versions
 _DB_TABLE_NAMES = {
     5: {
         "ASSET": "ZGENERICASSET",
@@ -60,6 +71,8 @@ _DB_TABLE_NAMES = {
         "ASSET_ALBUM_JOIN": "Z_26ASSETS.Z_26ALBUMS",
         "ASSET_ALBUM_TABLE": "Z_26ASSETS",
         "HDR_TYPE": "ZCUSTOMRENDEREDVALUE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSON",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSET",
     },
     6: {
         "ASSET": "ZASSET",
@@ -72,6 +85,8 @@ _DB_TABLE_NAMES = {
         "ASSET_ALBUM_JOIN": "Z_26ASSETS.Z_26ALBUMS",
         "ASSET_ALBUM_TABLE": "Z_26ASSETS",
         "HDR_TYPE": "ZCUSTOMRENDEREDVALUE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSON",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSET",
     },
     7: {
         "ASSET": "ZASSET",
@@ -84,6 +99,8 @@ _DB_TABLE_NAMES = {
         "ASSET_ALBUM_JOIN": "Z_27ASSETS.Z_27ALBUMS",
         "ASSET_ALBUM_TABLE": "Z_27ASSETS",
         "HDR_TYPE": "ZHDRTYPE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSON",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSET",
     },
     8: {
         "ASSET": "ZASSET",
@@ -96,6 +113,22 @@ _DB_TABLE_NAMES = {
         "ASSET_ALBUM_JOIN": "Z_28ASSETS.Z_28ALBUMS",
         "ASSET_ALBUM_TABLE": "Z_28ASSETS",
         "HDR_TYPE": "ZHDRTYPE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSON",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSET",
+    },
+    9: {
+        "ASSET": "ZASSET",
+        "KEYWORD_JOIN": "Z_1KEYWORDS.Z_40KEYWORDS",
+        "ALBUM_JOIN": "Z_28ASSETS.Z_3ASSETS",
+        "ALBUM_SORT_ORDER": "Z_28ASSETS.Z_FOK_3ASSETS",
+        "IMPORT_FOK": "null",
+        "DEPTH_STATE": "ZASSET.ZDEPTHTYPE",
+        "UTI_ORIGINAL": "ZINTERNALRESOURCE.ZCOMPACTUTI",
+        "ASSET_ALBUM_JOIN": "Z_28ASSETS.Z_28ALBUMS",
+        "ASSET_ALBUM_TABLE": "Z_28ASSETS",
+        "HDR_TYPE": "ZHDRTYPE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSONFORFACE",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSETFORFACE",
     },
 }
 
@@ -124,6 +157,10 @@ _TESTED_OS_VERSIONS = [
     ("13", "0"),
     ("13", "1"),
     ("13", "2"),
+    ("13", "3"),
+    ("13", "4"),
+    ("13", "5"),
+    ("14", "0"),
 ]
 
 # Photos 5 has persons who are empty string if unidentified face
@@ -464,3 +501,12 @@ PROFILE_SORT_KEYS = [
 UUID_PATTERN = (
     r"[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}"
 )
+# Reference: https://docs.python.org/3/library/sqlite3.html?highlight=sqlite3%20threadsafety#sqlite3.threadsafety
+# and https://docs.python.org/3/library/sqlite3.html?highlight=sqlite3%20threadsafety#sqlite3.connect
+# 3: serialized mode; Threads may share the module, connections and cursors
+# 3 is the default in the python.org python 3.11 distribution
+# earlier versions of python.org python 3.x default to 1 which means threads may not share
+# sqlite3 connections and thus PhotoInfo.export() cannot be used in a multithreaded environment
+# pass SQLITE_CHECK_SAME_THREAD to sqlite3.connect() to enable multithreaded access on systems that support it
+SQLITE_CHECK_SAME_THREAD = not sqlite3.threadsafety == 3
+logger.debug(f"{SQLITE_CHECK_SAME_THREAD=}, {sqlite3.threadsafety=}")
