@@ -9,12 +9,16 @@ import json
 import sys
 
 import click
-import photoscript
 
 import osxphotos
 from osxphotos.phototemplate import RenderOptions
+from osxphotos.platform import assert_macos
 from osxphotos.sqlitekvstore import SQLiteKVStore
 
+assert_macos()
+
+import photoscript
+
 from .cli_commands import echo, echo_error, selection_command, verbose
 from .kvstore import kvstore
 from .param_types import Latitude, Longitude, TemplateString
@@ -88,7 +92,7 @@ def batch_edit(
 
     This will set the title to "California vacation 2023 2023-02-20 001", and so on,
     the description to the reverse geolocation place name, 
-    and add the keywords to "Family", "Travel".
+    and add the keywords "Family" and "Travel".
 
     --title, --description, and --keyword may be any valid template string.
     See https://rhettbull.github.io/osxphotos/template_help.html 
