@@ -20,12 +20,11 @@ from textwrap import dedent
 from typing import Callable, Dict, List, Optional, Tuple, Union
 
 import click
-from photoscript import Photo, PhotosLibrary
 from rich.console import Console
 from rich.markdown import Markdown
 from strpdatetime import strpdatetime
 
-from osxphotos._constants import _OSXPHOTOS_NONE_SENTINEL
+from osxphotos._constants import _OSXPHOTOS_NONE_SENTINEL, SQLITE_CHECK_SAME_THREAD
 from osxphotos._version import __version__
 from osxphotos.cli.cli_params import TIMESTAMP_OPTION, VERBOSE_OPTION
 from osxphotos.cli.common import get_data_dir
@@ -42,9 +41,15 @@ from osxphotos.exiftool import ExifToolCaching, get_exiftool_path
 from osxphotos.photoinfo import PhotoInfoNone
 from osxphotos.photosalbum import PhotosAlbumPhotoScript
 from osxphotos.phototemplate import PhotoTemplate, RenderOptions
+from osxphotos.platform import assert_macos
 from osxphotos.sqlitekvstore import SQLiteKVStore
+from osxphotos.unicode import normalize_unicode
 from osxphotos.utils import pluralize
 
+assert_macos()
+
+from photoscript import Photo, PhotosLibrary
+
 from .cli_params import THEME_OPTION
 from .click_rich_echo import rich_click_echo, rich_echo_error
 from .rich_progress import rich_progress
@@ -77,7 +82,8 @@ def echo(message, emoji=True, **kwargs):
 class PhotoInfoFromFile:
     """Mock PhotoInfo class for a file to be imported
 
-    Returns None for most attributes but allows some templates like exiftool and created to work correctly"""
+    Returns None for most attributes but allows some templates like exiftool and created to work correctly
+    """
 
     def __init__(self, filepath: Union[str, Path], exiftool: Optional[str] = None):
         self._path = str(filepath)
@@ -353,11 +359,12 @@ def set_photo_metadata(
     merge_keywords: bool,
 ) -> MetaData:
     """Set metadata (title, description, keywords) for a Photo object"""
-    photo.title = metadata.title
-    photo.description = metadata.description
+    photo.title = normalize_unicode(metadata.title)
+    photo.description = normalize_unicode(metadata.description)
     keywords = metadata.keywords.copy()
+    keywords = normalize_unicode(keywords)
     if merge_keywords:
-        if old_keywords := photo.keywords:
+        if old_keywords := normalize_unicode(photo.keywords):
             keywords.extend(old_keywords)
             keywords = list(set(keywords))
     photo.keywords = keywords
@@ -416,7 +423,7 @@ def set_photo_title(
         verbose(
             f"Setting title of photo [filename]{filepath.name}[/] to '{title_text[0]}'"
         )
-        photo.title = title_text[0]
+        photo.title = normalize_unicode(title_text[0])
         return title_text[0]
     else:
         return ""
@@ -444,7 +451,7 @@ def set_photo_description(
         verbose(
             f"Setting description of photo [filename]{filepath.name}[/] to '{description_text[0]}'"
         )
-        photo.description = description_text[0]
+        photo.description = normalize_unicode(description_text[0])
         return description_text[0]
     else:
         return ""
@@ -465,8 +472,9 @@ def set_photo_keywords(
         kw = render_photo_template(filepath, relative_filepath, keyword, exiftool_path)
         keywords.extend(kw)
     if keywords:
+        keywords = normalize_unicode(keywords)
         if merge:
-            if old_keywords := photo.keywords:
+            if old_keywords := normalize_unicode(photo.keywords):
                 keywords.extend(old_keywords)
                 keywords = list(set(keywords))
         verbose(f"Setting keywords of photo [filename]{filepath.name}[/] to {keywords}")
@@ -745,7 +753,7 @@ def write_sqlite_report(
 
     file_exists = os.path.isfile(report_file)
 
-    conn = sqlite3.connect(report_file)
+    conn = sqlite3.connect(report_file, check_same_thread=SQLITE_CHECK_SAME_THREAD)
     c = conn.cursor()
 
     if not append or not file_exists:
@@ -1414,7 +1422,13 @@ def import_cli(
     verbose_flag,
     walk,
 ):
-    """Import photos and videos into Photos."""
+    """Import photos and videos into Photos. Photos will be imported into the
+    most recently opened Photos library.
+
+    Photos are imported one at a time thus the "Imports" album in Photos will show
+    a new import group for each photo imported. Batch import into a single import
+    group will be added in a future release.
+    """
 
     verbose = verbose_print(verbose=verbose_flag, timestamp=timestamp, theme=theme)
 
