@@ -21,7 +21,6 @@ from ._version import __version__
 from .datetime_formatter import DateTimeFormatter
 from .exiftool import ExifToolCaching
 from .path_utils import sanitize_dirname, sanitize_filename, sanitize_pathpart
-from .text_detection import detect_text
 from .utils import expand_and_validate_filepath, load_function, uuid_to_shortuuid
 
 __all__ = [
@@ -360,7 +359,7 @@ class RenderOptions:
     dirname: if True, template output will be sanitized to produce valid directory name
     strip: if True, strips leading/trailing whitespace from rendered templates
     edited_version: set to True if you want {edited_version} to resolve to True (e.g. exporting edited version of photo)
-    export_dir: set to the export directory if you want to evalute {export_dir} template
+    export_dir: set to the export directory if you want to evaluate {export_dir} template
     dest_path: set to the destination path of the photo (for use by {function} template), only valid with --filename
     filepath: set to value for filepath of the exported photo if you want to evaluate {filepath} template
     quote: quote path templates for execution in the shell
@@ -465,7 +464,7 @@ class PhotoTemplate:
             ([rendered_strings], [unmatched]): tuple of list of rendered strings and list of unmatched template values
         """
 
-        if type(template) is not str:
+        if not isinstance(template, str):
             raise TypeError(f"template must be type str, not {type(template)}")
 
         self.options = options
@@ -627,7 +626,7 @@ class PhotoTemplate:
 
             if self.expand_inplace or delim is not None:
                 sep = delim if delim is not None else self.inplace_sep
-                vals = [sep.join(sorted(vals))] if vals else []
+                vals = [sep.join(vals)] if vals else []
 
             for filter_ in filters:
                 vals = self.get_filter_values(filter_, vals)
@@ -734,7 +733,7 @@ class PhotoTemplate:
             pre = ts.pre or ""
             post = ts.post or ""
 
-            rendered = [pre + val + post for val in vals]
+            rendered = [pre + str(val) + post for val in vals]
             results_new = []
             for ren in rendered:
                 for res in results:
@@ -1153,7 +1152,7 @@ class PhotoTemplate:
                 )
             except ValueError as e:
                 raise SyntaxError(
-                    f"comparison operators may only be used with values that can be converted to numbers: {vals} {conditional_value}"
+                    f"comparison operators may only be used with values that can be converted to numbers: {value} {conditional_value}"
                 ) from e
 
         predicate_is_true = False
@@ -1212,15 +1211,19 @@ class PhotoTemplate:
             values = self.photo.burst_albums if self.photo.burst else self.photo.albums
             values += [p.title for p in self.photo.project_info]
         elif field == "keyword":
-            values = self.photo.keywords
+            values = sorted(self.photo.keywords) if self.photo.keywords else []
         elif field == "person":
-            values = self.photo.persons
+            values = sorted(self.photo.persons) if self.photo.persons else []
             # remove any _UNKNOWN_PERSON values
             values = [val for val in values if val != _UNKNOWN_PERSON]
         elif field == "label":
-            values = self.photo.labels
+            values = sorted(self.photo.labels) if self.photo.labels else []
         elif field == "label_normalized":
-            values = self.photo.labels_normalized
+            values = (
+                sorted(self.photo.labels_normalized)
+                if self.photo.labels_normalized
+                else []
+            )
         elif field in ["folder_album", "folder_album_project"]:
             values = []
             # photos must be in an album to be in a folder
@@ -1247,6 +1250,7 @@ class PhotoTemplate:
                     values.append(sanitize_dirname(album.title))
                 else:
                     values.append(album.title)
+            values = sorted(values)
         elif field == "comment":
             values = [
                 f"{comment.user}: {comment.text}" for comment in self.photo.comments
@@ -1293,7 +1297,10 @@ class PhotoTemplate:
             elif isinstance(obj, (str, int, float)):
                 values = [str(obj)]
             else:
-                values = list(obj)
+                try:
+                    values = [str(o) for o in obj]
+                except TypeError:
+                    values = [str(obj)]
         elif field == "detected_text":
             values = _get_detected_text(self.photo, confidence=subfield)
         else:
@@ -1352,7 +1359,7 @@ class PhotoTemplate:
         subfield = subfield.lower()
         if subfield in exifdict:
             values = exifdict[subfield]
-            values = [values] if not isinstance(values, list) else values
+            values = values if isinstance(values, list) else [values]
             values = [str(v) for v in values]
 
             # sanitize directory names if needed
@@ -1396,7 +1403,7 @@ class PhotoTemplate:
             # if no uuid, then template is being validated but not actually run
             # so don't run the function
             values = []
-        elif caller in ["export", "query"]:
+        elif caller in {"export", "query"}:
             # function signature is:
             # def example(photo: PhotoInfo, options: ExportOptions, args: Optional[str] = None, **kwargs) -> Union[List, str]:
             values = template_func(self.photo, options=self.options, args=field_arg)
@@ -1412,7 +1419,7 @@ class PhotoTemplate:
             raise TypeError(
                 f"Invalid return type for function {funcname}: expected str or list"
             )
-        if type(values) == str:
+        if isinstance(values, str):
             values = [values]
 
         # sanitize directory names if needed
@@ -1682,7 +1689,7 @@ def format_date_field(dt: datetime.datetime, field: str, args: List[str]) -> str
             raise ValueError(f"Unhandled template value: {field}") from e
 
 
-def get_place_value(photo: "PhotoInfo", field: str):
+def get_place_value(photo: "PhotoInfo", field: str):  # noqa: F821
     """Get the value of a 'place' field by attribute
 
     Args:
