@@ -18,9 +18,19 @@ if is_macos:
 else:
     pytest.skip(allow_module_level=True)
 
-# set timezone to avoid issues with comparing dates
-os.environ["TZ"] = "US/Pacific"
-time.tzset()
+
+@pytest.fixture(scope="module", autouse=True)
+def set_timezone():
+    """Set timezone to US/Pacific for all tests"""
+    old_tz = os.environ.get("TZ")
+    os.environ["TZ"] = "US/Pacific"
+    time.tzset()
+    yield
+    if old_tz:
+        os.environ["TZ"] = old_tz
+    else:
+        del os.environ["TZ"]
+    time.tzset()
 
 
 TEST_DATA_BATCH_EDIT = {
