@@ -7,6 +7,7 @@ import pytest
 import osxphotos
 from osxphotos.exiftool import get_exiftool_path
 from osxphotos.export_db import ExportDBInMemory
+from osxphotos.photoinfo import PhotoInfoNone
 from osxphotos.phototemplate import (
     PUNCTUATION,
     TEMPLATE_SUBSTITUTIONS,
@@ -14,7 +15,9 @@ from osxphotos.phototemplate import (
     PhotoTemplate,
     RenderOptions,
 )
-from osxphotos.photoinfo import PhotoInfoNone
+from osxphotos.platform import is_macos
+
+from .locale_util import setlocale
 from .photoinfo_mock import PhotoInfoMock
 
 try:
@@ -71,13 +74,11 @@ TEMPLATE_VALUES_MULTI_KEYWORDS = {
     "{keyword|titlecase}": ["Flowers", "Wedding"],
     "{keyword|capitalize}": ["Flowers", "Wedding"],
     "{keyword|shell_quote}": ["flowers", "wedding"],
-    "{+keyword}": ["flowerswedding"],
-    "{+keyword|titlecase}": ["Flowerswedding"],
-    "{+keyword|capitalize}": ["Flowerswedding"],
-    "{;+keyword}": ["flowers;wedding"],
-    "{; +keyword}": ["flowers; wedding"],
-    "{; +keyword|titlecase}": ["Flowers; Wedding"],
-    "{; +keyword|titlecase|parens}": ["(Flowers; Wedding)"],
+    "{var:kw,{keyword|sort}}{%kw|join(,)}": ["flowers,wedding"],
+    "{var:kw,{keyword|sort}}{%kw|titlecase|join(;)}": ["Flowers;Wedding"],
+    "{,+keyword}": ["flowers,wedding"],  # test keywords in sorted order
+    "{,+keyword|titlecase}": ["Flowers,Wedding"],  # test keywords in sorted order
+    "{,+keyword|upper}": ["FLOWERS,WEDDING"],  # test keywords in sorted order
     "{keyword|appends(:keyword)}": ["flowers:keyword", "wedding:keyword"],
     "{keyword|prepends(keyword:)}": ["keyword:flowers", "keyword:wedding"],
 }
@@ -376,7 +377,6 @@ UUID_CONDITIONAL = {
         "{title contains Park?YES,NO}": ["YES"],
         "{title not contains Park?YES,NO}": ["NO"],
         "{title matches Park?YES,NO}": ["NO"],
-        "{title matches Elder Park?YES,NO}": ["YES"],
         "{title == Elder Park?YES,NO}": ["YES"],
         "{title != Elder Park?YES,NO}": ["NO"],
         "{title[ ,] == ElderPark?YES,NO}": ["YES"],
@@ -386,7 +386,6 @@ UUID_CONDITIONAL = {
         "{title endswith Elder?YES,NO}": ["NO"],
         "{title startswith Elder?YES,NO}": ["YES"],
         "{title startswith Elder|endswith Park?YES,NO}": ["YES"],
-        "{title endswith Elder?YES,NO}": ["NO"],
         "{photo.place.name contains Adelaide?YES,NO}": ["YES"],
         "{photo.place.name|lower contains adelaide?YES,NO}": ["YES"],
         "{photo.place.name|lower contains adelaide|australia?YES,NO}": ["YES"],
@@ -474,6 +473,7 @@ UUID_MOMENT = {
 
 UUID_EMPTY_TITLE = "7783E8E6-9CAC-40F3-BE22-81FB7051C266"  # IMG_3092.heic
 UUID_EMPTY_TITLE_HAS_DESCRIPTION = "E9BC5C36-7CD1-40A1-A72B-8B8FAC227D51"  # wedding.jpg
+UUID_LAT_LON = "7783E8E6-9CAC-40F3-BE22-81FB7051C266"  # IMG_3092.heic
 
 TEMPLATE_VALUES_EMPTY_TITLE = {
     "{title,No Title} and {descr,No Descr}": "No Title and No Descr",
@@ -549,6 +549,8 @@ def test_lookup_multi(photosdb_places):
         lookup_str = re.match(r"\{([^\\,}]+)\}", subst).group(1)
         if subst in ["{exiftool}", "{photo}", "{function}", "{format}"]:
             continue
+        if subst == "{detected_text}" and not is_macos:
+            continue
         lookup = template.get_template_value_multi(
             lookup_str,
             path_sep=os.path.sep,
@@ -562,7 +564,7 @@ def test_subst(photosdb_places):
     """Test that substitutions are correct"""
     import locale
 
-    locale.setlocale(locale.LC_ALL, "en_US")
+    setlocale(locale.LC_ALL, "en_US")
     photo = photosdb_places.photos(uuid=[UUID_DICT["place_dc"]])[0]
 
     for template in TEMPLATE_VALUES:
@@ -574,7 +576,7 @@ def test_subst_date_modified(photosdb_places):
     """Test that substitutions are correct for date modified"""
     import locale
 
-    locale.setlocale(locale.LC_ALL, "en_US")
+    setlocale(locale.LC_ALL, "en_US")
     photo = photosdb_places.photos(uuid=[UUID_DICT["date_modified"]])[0]
 
     for template in TEMPLATE_VALUES_DATE_MODIFIED:
@@ -586,7 +588,7 @@ def test_subst_date_not_modified(photosdb_places):
     """Test that substitutions are correct for date modified when photo isn't modified"""
     import locale
 
-    locale.setlocale(locale.LC_ALL, "en_US")
+    setlocale(locale.LC_ALL, "en_US")
     photo = photosdb_places.photos(uuid=[UUID_DICT["date_not_modified"]])[0]
 
     for template in TEMPLATE_VALUES_DATE_NOT_MODIFIED:
@@ -600,7 +602,7 @@ def test_subst_locale_1(photosdb_places):
 
     # osxphotos.template sets local on load so set the environment first
     # set locale to DE
-    locale.setlocale(locale.LC_ALL, "de_DE.UTF-8")
+    setlocale(locale.LC_ALL, "de_DE.UTF-8")
 
     photo = photosdb_places.photos(uuid=[UUID_DICT["place_dc"]])[0]
 
@@ -614,6 +616,9 @@ def test_subst_locale_2(photosdb_places):
     import locale
     import os
 
+    # Check if locale is available
+    setlocale(locale.LC_ALL, "de_DE.UTF-8")
+
     # osxphotos.template sets local on load so set the environment first
     os.environ["LANG"] = "de_DE.UTF-8"
     os.environ["LC_COLLATE"] = "de_DE.UTF-8"
@@ -634,7 +639,7 @@ def test_subst_default_val(photosdb_places):
     """Test substitution with default value specified"""
     import locale
 
-    locale.setlocale(locale.LC_ALL, "en_US")
+    setlocale(locale.LC_ALL, "en_US")
     photo = photosdb_places.photos(uuid=[UUID_DICT["place_dc"]])[0]
 
     template = "{place.name.area_of_interest,UNKNOWN}"
@@ -646,7 +651,7 @@ def test_subst_default_val_2(photosdb_places):
     """Test substitution with ',' but no default value"""
     import locale
 
-    locale.setlocale(locale.LC_ALL, "en_US")
+    setlocale(locale.LC_ALL, "en_US")
     photo = photosdb_places.photos(uuid=[UUID_DICT["place_dc"]])[0]
 
     template = "{place.name.area_of_interest,}"
@@ -658,7 +663,7 @@ def test_subst_unknown_val(photosdb_places):
     """Test substitution with unknown value specified"""
     import locale
 
-    locale.setlocale(locale.LC_ALL, "en_US")
+    setlocale(locale.LC_ALL, "en_US")
     photo = photosdb_places.photos(uuid=[UUID_DICT["place_dc"]])[0]
 
     template = "{created.year}/{foo}"
@@ -682,7 +687,7 @@ def test_subst_unknown_val_with_default(photosdb_places):
     """Test substitution with unknown value specified"""
     import locale
 
-    locale.setlocale(locale.LC_ALL, "en_US")
+    setlocale(locale.LC_ALL, "en_US")
     photo = photosdb_places.photos(uuid=[UUID_DICT["place_dc"]])[0]
 
     template = "{created.year}/{foo,bar}"
@@ -929,7 +934,7 @@ def test_subst_strftime(photosdb_places):
     """Test that strftime substitutions are correct"""
     import locale
 
-    locale.setlocale(locale.LC_ALL, "en_US")
+    setlocale(locale.LC_ALL, "en_US")
     photo = photosdb_places.photos(uuid=[UUID_DICT["place_dc"]])[0]
 
     rendered, unmatched = photo.render_template("{created.strftime,%Y-%m-%d-%H%M%S}")
@@ -1128,7 +1133,8 @@ def test_nested_template(photosdb):
     assert rendered == ["My Title"]
 
 
-def test_punctuation(photosdb):
+def test_punctuation_1(photosdb):
+    """Test punctuation template fields"""
     from osxphotos.phototemplate import PUNCTUATION
 
     photo = photosdb.get_photo(UUID_MULTI_KEYWORDS)
@@ -1137,6 +1143,19 @@ def test_punctuation(photosdb):
         assert rendered[0] == PUNCTUATION[punc]
 
 
+def test_punctuation_2():
+    """Test punctuation template fields"""
+    template_string = ""
+    expected_string = ""
+    for field, value in PUNCTUATION.items():
+        template_string += "{" + field + "}"
+        expected_string += f"{value}"
+    template = PhotoTemplate(PhotoInfoNone())
+    options = RenderOptions()
+    rendered, _ = template.render(template_string, options)
+    assert rendered == [expected_string]
+
+
 def test_photo_template(photosdb):
     for uuid in UUID_PHOTO:
         photo = photosdb.get_photo(uuid)
@@ -1287,6 +1306,7 @@ def test_album_seq(photosdb):
             assert rendered[0] == value
 
 
+@pytest.mark.skipif(not is_macos, reason="Only works on macOS")
 def test_detected_text(photosdb):
     """Test {detected_text} template"""
     photo = photosdb.get_photo(UUID_DETECTED_TEXT)
@@ -1354,14 +1374,24 @@ def test_bad_sslice(photosdb):
         rendered, _ = photo.render_template("{photo.original_filename|sslice(1:2:3:4)}")
 
 
-def test_punctuation():
-    """Test punctuation template fields"""
-    template_string = ""
-    expected_string = ""
-    for field, value in PUNCTUATION.items():
-        template_string += "{" + field + "}"
-        expected_string += f"{value}"
-    template = PhotoTemplate(PhotoInfoNone())
-    options = RenderOptions()
-    rendered, _ = template.render(template_string, options)
-    assert rendered == [expected_string]
+def test_location_latitude_longitude(photosdb):
+    """Test {photo.location}, {photo.latitude}, {photo.longitude} #1187"""
+    photo = photosdb.get_photo(UUID_LAT_LON)
+    rendered, _ = photo.render_template("{photo.location}")
+    assert len(rendered) == 2
+    assert float(rendered[0]) == pytest.approx(41.256566)
+    assert float(rendered[1]) == pytest.approx(-95.940257)
+
+    rendered, _ = photo.render_template("{photo.latitude}")
+    assert float(rendered[0]) == pytest.approx(41.256566)
+
+    rendered, _ = photo.render_template("{photo.longitude}")
+    assert float(rendered[0]) == pytest.approx(-95.940257)
+
+
+def test_float_concatenation(photosdb):
+    """Test {,+photo.location} #1197"""
+    photo = photosdb.get_photo(UUID_LAT_LON)
+    rendered, _ = photo.render_template("{,+photo.location}")
+    assert len(rendered) == 1
+    assert rendered[0] == f"{photo.location[0]},{photo.location[1]}"
